@@ -845,7 +845,7 @@ cx_config_edit(void)
 			if (panel_cfg.pd->curs >= 1) {
 				config_changes();
 				config_apply();
-				if (param == 2)
+				if (panel_cfg.pd->curs == 2)
 					config_save();
 			}
 			next_mode = MODE_SPECIAL_RETURN;
