@@ -102,6 +102,20 @@ typedef struct {
 	FLAG admin;					/* admin mode: clex -a */
 } CLEX_DATA;
 
+/* description of an editing operation */
+# define OP_NONE	0	/* no change (cursor movement is OK) */
+# define OP_INS		1	/* simple insert */
+# define OP_DEL		2	/* simple deletion */
+# define OP_CHANGE	3	/* modification other than insert or delete */
+typedef struct {
+	int code;		/* one of OP_XXX defined above */
+/* 'pos' and 'len' are used with OP_INSERT and OP_DELETE only */
+	int pos;		/* position within the edited string */
+	int len;		/* length of the inserted/deleted part */
+} EDIT_OP;
+
+#define UNDO_LEVELS 10	/* undo steps */
+
 /* line of text where the user can enter and edit his/her input */
 typedef struct {
 	const char *prompt;	/* prompt */
@@ -111,12 +125,17 @@ typedef struct {
 	int curs;			/* cursor position from 0 to 'size' */
 	int offset;			/* offset - when the line is too long,
 						   first 'offset' characters are hidden */
-	/* values copied for the UNDO function */
-	FLAG undo_possible;
-	USTRING save_line;
-	int save_size;
-	int save_curs;
-	int save_offset;
+	/* values for the UNDO function */
+	struct {
+		USTRING save_line;
+		int save_size;
+		int save_curs;
+		int save_offset;
+	} undo [UNDO_LEVELS];	/* used in a circular manner */
+	int undo_base;			/* index of the first entry */
+	int undo_levels;		/* occupied entries for undo */
+	int redo_levels;		/* free entries usable for redo */
+	EDIT_OP last_op;		/* last editing operation */
 } TEXTLINE;
 
 /********************************************************************/
@@ -142,7 +161,7 @@ typedef struct {
 	/*
 	 * panel line 'min' is either 0 or -1. If set to -1 a special
 	 * line numbered -1 with the text
-     *     --- (leave this panel) ---
+     *     --- (leave this panel / ctrl-C) ---
      * is inserted before actual first line which is always
 	 * line number 0
 	 */
@@ -155,7 +174,7 @@ typedef struct {
 
 /*
  * file types recognized in the file panel
- * if you change this, you must also update text symbols in inout.c
+ * if you change this, you must also update the names of the types in inout.c
  */
 #define FT_PLAIN_FILE		 0
 #define FT_PLAIN_EXEC		 1
@@ -206,8 +225,8 @@ typedef struct {
 	unsigned int symlink:1;		/* flag: it is a symbolic link */
 	unsigned int dotdir:2;		/* . (1) or .. (2) directory */
 	/*
-	 * note: all structure members below are not used
-	 * if the file panel layout does not require them
+	 * note: the structure members below are used
+	 * only when the file panel layout requires them
 	 */
 	unsigned int normal_mode:1;	/* file mode same as "normal" file */
 	unsigned int links:1;		/* has multiple hard links */
