@@ -253,10 +253,11 @@ register_candidate(const char *cand, int is_link, int file_type,
 	size_t i;
 	static const char *cand0;
 
-	if (rq.type == COMPL_TYPE_PATHCMD)
-		/* check for duplicates, like awk in /bin and /usr/bin */
+	if (rq.type == COMPL_TYPE_PATHCMD && IS_FT_EXEC(file_type))
+		/* check for duplicates like awk in both /bin and /usr/bin */
 		for (i = 0; i < compl.cnt && i < cc_max; i++)
-			if (strcmp(SDSTR(CC_LIST[i].str),cand) == 0)
+			if (strcmp(SDSTR(CC_LIST[i].str),cand) == 0 &&
+			  IS_FT_EXEC(CC_LIST[i].file_type))
 				return;
 
 	if (compl.cnt < cc_max) {
