@@ -40,7 +40,7 @@
 #include "select.h"			/* select_prepare() */
 #include "sort.h"			/* sort_prepare() */
 #include "tty.h"			/* tty_reset() */
-#include "undo.h"			/* undo_before() */
+#include "undo.h"			/* undo_reset() */
 #include "xterm_title.h"	/* xterm_title_restore() */
 
 /*
@@ -160,6 +160,7 @@ static KEY_BINDING tab_edit[] = {
 #endif
 	{ 0,  CH_CTRL('Y'),	cx_edit_delend		},
 	{ 0,  CH_CTRL('Z'),	cx_undo				},
+	{ 1,  CH_CTRL('Z'),	cx_redo				},
 	{ 0,  '\177',		cx_edit_delchar		},
 	{ 0,  KEY_DC,		cx_edit_delchar		},
 	{ 0,  KEY_LEFT,		cx_edit_left		},
@@ -475,8 +476,7 @@ control_loop(int mode)
 			win_panel();
 		}
 		if (textline != clex_mode->textline) {
-			if (textline)
-				textline->undo_possible = 0;
+			undo_reset();
 			clex_mode->textline = textline;
 			win_edit();
 		}
