@@ -29,6 +29,7 @@
 #include "inout.h"			/* win_panel() */
 #include "panel.h"			/* pan_adjust() */
 #include "sdstring.h"		/* sd_reset() */
+#include "undo.h"			/* undo_init() */
 #include "ustring.h"		/* us_reset() */
 #include "userdata.h"		/* dir_tilde() */
 #include "util.h"			/* emalloc() */
@@ -76,7 +77,7 @@ dir_initialize(void)
 	}
 
 	US_INIT(line_dir.line);
-	US_INIT(line_dir.save_line);
+	undo_init(&line_dir);
 	edit_setprompt(&line_dir,"Change directory: ");
 
 	dir_reconfig();
