@@ -44,6 +44,7 @@
 #include "history.h"		/* hist_save() */
 #include "list.h"			/* list_directory() */
 #include "tty.h"			/* tty_setraw() */
+#include "undo.h"			/* undo_init() */
 #include "util.h"			/* base_name() */
 #include "userdata.h"		/* dir_tilde() */
 #include "ustring.h"		/* us_copy() */
@@ -60,7 +61,7 @@ void
 exec_initialize(void)
 {
 	US_INIT(line_cmd.line);
-	US_INIT(line_cmd.save_line);
+	undo_init(&line_cmd);
 
 	exec_shell_reconfig();
 	exec_prompt_reconfig();	/* prompt needs to know the shell */
