@@ -26,6 +26,7 @@
 #include "exec.h"			/* execute_cmd() */
 #include "inout.h"			/* win_remark() */
 #include "panel.h"			/* pan_adjust() */
+#include "undo.h"			/* undo_reset() */
 #include "util.h"			/* emalloc() */
 #include "ustring.h"		/* us_copy() */
 
@@ -146,7 +147,7 @@ cx_hist_prev(void)
 	}
 
 	if (++pn_index == 0)
-		us_copy(&save_line,USTR(line_cmd.line));
+		us_xchg(&save_line,&line_cmd.line);
 	edit_putstr(USTR(HS_LIST[pn_index]->cmd));
 	warn_fail(pn_index);
 }
@@ -196,7 +197,7 @@ cx_hist_enter(void)
 
 	if (execute_cmd(cmd)) {
 		cx_edit_kill();
-		textline->undo_possible = 0;
+		undo_reset();
 	}
 }
 
