@@ -149,7 +149,6 @@ list_reconfig(void)
 		tpad = dlen - tlen;
 		display.date_len = dlen;
 	}
-	/* note: max padding is 11 - 5 = 6 spaces */
 
 	/* FMT_NUMBER */
 	switch (config_num(CFG_FMT_NUMBER)) {
@@ -207,8 +206,9 @@ list_initialize(void)
 static void
 stat2time(char *str, time_t tm)
 {
-	int i, len;
+	int i, len, hour;
 	char ch;
+	const char *ampm;
 	struct tm *ptm;
 	static char *month[] = {
 		"jan", "feb", "mar", "apr", "may", "jun",
@@ -219,51 +219,51 @@ stat2time(char *str, time_t tm)
 	/* print time of day, after 18 hrs (64800s) print date */
 	/* 5 mins (300s) tolerance */
 	if (tm <= now + 300 && now <= tm + 64800L) {
-		if (tpad)
-			strcpy(str,"      ");	/* max padding 6 spaces */
-		if (clock24)
-			sprintf(str + tpad,"%02d:%02d",ptm->tm_hour,ptm->tm_min);
-		else
-			sprintf(str + tpad,"%02d:%02d%s",
-			  1 + (ptm->tm_hour + 11) % 12,
-			  ptm->tm_min,ptm->tm_hour < 12 ? "am" : "pm" );
+		if (clock24) {
+			hour = ptm->tm_hour;
+			ampm = "";
+		}
+		else {
+			hour = 1 + (ptm->tm_hour + 11) % 12;
+			ampm = ptm->tm_hour < 12 ? "am" : "pm";
+		}
+		for (len = 0; len < tpad; len++)
+			*str++ = ' ';
+		sprintf(str,"%02d:%02d%s",hour,ptm->tm_min,ampm);
 	}
 	else {
-		len = 0;
-		if (dpad) {
-			strcpy(str,"      ");	/* max padding 6 spaces */
-			len += dpad;
-		}
+		for (len = 0; len < dpad; len++)
+			*str++ = ' ';
 		for (i = 0; (ch = fmt_date[i]); i++) {
 			switch (ch) {
 			case 'Y':
 				/* Y10K compliant ;-) */
-				sprintf(str + len,"%04d",(1900 + ptm->tm_year) % 10000);
-				len += 4;
+				sprintf(str,"%04d",(1900 + ptm->tm_year) % 10000);
+				str += 4;
 				break;
 			case 'y':
-				sprintf(str + len,"%02d",ptm->tm_year % 100);
-				len += 2;
+				sprintf(str,"%02d",ptm->tm_year % 100);
+				str += 2;
 				break;
 			case 'M':
-				strcpy(str + len,month[ptm->tm_mon]);
-				len += 3;
+				strcpy(str,month[ptm->tm_mon]);
+				str += 3;
 				break;
 			case 'm':
-				sprintf(str + len,"%02d",ptm->tm_mon + 1);
-				len += 2;
+				sprintf(str,"%02d",ptm->tm_mon + 1);
+				str += 2;
 				break;
 			case 'd':
-				sprintf(str + len,"%02d",ptm->tm_mday);
-				len += 2;
+				sprintf(str,"%02d",ptm->tm_mday);
+				str += 2;
 				break;
 			case 'D':
-				sprintf(str + len,"%2d",ptm->tm_mday);
-				len += 2;
+				sprintf(str,"%2d",ptm->tm_mday);
+				str += 2;
 				break;
 			default:
-				str[len++] = ch;
-				str[len] = '\0';
+				*str++ = ch;
+				*str   = '\0';
 			}
 		}
 	}
