@@ -36,6 +36,7 @@
 #include "list.h"		/* list_initialize() */
 #include "signals.h"	/* signal_initialize() */
 #include "tty.h"		/* tty_initialize() */
+#include "undo.h"		/* undo_init() */
 #include "userdata.h"	/* userdata_initialize() */
 #include "ustring.h"	/* US_INIT() */
 #include "util.h"		/* base_name() */
@@ -156,7 +157,7 @@ main(int argc, char *argv[])
 	clex_data.isroot = geteuid() == 0;  /* 0 or 1 */;
 
 	US_INIT(line_tmp.line);	/* belongs to nowhere, initialize it here */
-	US_INIT(line_tmp.save_line);
+	undo_init(&line_tmp);
 
 	signal_initialize();	/* set signal dispositions */
 	userdata_initialize();	/* must be done before config */
