@@ -25,7 +25,7 @@
 #include "util.h"
 
 #include "control.h"			/* err_exit() */
-#include "ustring.h"			/* us_copy() */
+#include "ustring.h"			/* us_resize() */
 
 /* variables used in pathname_xxx() functions */
 static USTRING sf_buff = { 0,0 };
